# Настройки SDK Payout API ЮKassa

[Протокол массовых выплат ЮKassa](https://yookassa.ru/docs/payouts)

С помощью этого SDK можно делать выплаты на кошельки ЮMoney, номера мобильных телефонов, банковские карты и счета.
Также можно сгенерировать запрос на получение сертификата для взаимодействия с серверами ЮKassa.

* [Получение сертификата для аутентификации запросов](#Получение-сертификата-для-аутентификации-запросов)
* [Запрос баланса](#Запрос-баланса)

---

## Получение сертификата для аутентификации запросов

Для аутентификации соединений с серверами ЮKassa вам нужен сертификат, выданный удостоверяющим
центром ООО НКО «ЮМани» (NBCO YooMoney). Чтобы его получить, вам нужно создать запрос на сертификат (в формате CSR),
заполнить заявку на получение сертификата и отправить запрос и заявку на сертификат по электронной почте своему
менеджеру в ЮKassa.

Для взаимодействия с ЮKassa необходимо получить сертификат. Для этого:
1. [Создайте закрытый ключ и запрос на получение сертификата (CSR)](#Шаг-1-Создание-приватного-ключа-и-CSR);
2. [Заполните заявку на сертификат](#Шаг-2-Заполнение-заявки-на-сертификат);
3. [Обменяйтесь данными с ЮKassa](#Шаг-3-Обмен-данными-с-ЮKassa).

### Шаг 1. Создание приватного ключа и CSR
#### С помощью метода SDK
```php
require_once '../vendor/autoload.php';

// Создание экземпляра клиента
$client  = new YooKassaPayout\Client(); 

// Заполнение данных организации
$organization = new YooKassaPayout\Model\Organization();
$organization->setEmailAddress('predpriyatie@yoomoney.ru')
             ->setOrganizationName('OOO Predpriyatie')
             ->setCommonName('/business/predpriyatie');

// Для создания нового закрытого ключа
try {
    $signature = $client->createCsr(
        $organization,                // Данные организации
        realpath('./files/'),         // Путь для генерации файлов
        '123456',                     // Пароль закрытого ключа
        null,                         // Пропускаем, т.к. генерируем новый закрытый ключ
        ['config' => './openssl.cnf'] // Обязательно для Windows
    );
    print_r($signature);              // Распечатка текстового представления электронной подписи
} catch (Exception $e) {
    print_r($e);
}

// Для использования старого закрытого ключа
try {
    $signature = $client->createCsr(
        $organization,                // Данные организации
        realpath('./files/'),         // Путь для генерации файлов
        '123456',                     // Пароль закрытого ключа
        './files/privateKey.pem',     // Путь у существующему закрытому ключу
        ['config' => './openssl.cnf'] // Обязательно для Windows
    );
    print_r($signature);              // Распечатка текстового представления электронной подписи
} catch (Exception $e) {
    print_r($e);
}
```
В результате SDK сгенерирует закрытый ключ, CSR и текстовый файл с электронной подписью (нужно для дальнейших шагов).

#### Через консоль
1. В консоли перейдите в папку вашего проекта, где расположен SDK.
```bash
cd <путь к SDK>
```
2. Выполните команду:
```bash
php bin/yoomoney get:csr
```
или, если есть существующий закрытый ключ:
```bash
php bin/yoomoney get:csr -k ./files/privateKey.pem
```
3. Введите данные для сертификата, следуя указаниям на экране. Текст необходимо вводить латинскими буквами.
   В результате SDK сгенерирует закрытый ключ, CSR и текстовый файл с электронной подписью (нужно для дальнейших шагов).
   
**Пример:**
```bash
$yookassa-payout-sdk-php: php lib/bin/yoomoney get:csr -c ./output/openssl.cnf
country name [RU]:
state or province name [Russia]:
organization name (название организации латинскими буквами): MyOrg
common name (начинается с /business/, после — любое сочетание латинских букв без пробелов): /business/myorg
email address (адрес электронной почты): test@yoomoney.ru
organizational unit name (не требуется, нажмите Enter для продолжения):
locality name (не требуется, нажмите Enter для продолжения):
Введите каталог для privateKey и request.csr [C:\ProgramData\OSPanel\domains\cmssdk.local\yookassa-payout-sdk-php\lib\Client]: ./output/files2
Введите пароль для приватного ключа (если не требуется, нажмите Enter для продолжения): 123456

7e:a2:d5:55:06:1a:e4:f5:aa:aa:d6:dc:90:bc:03:a7:d5:3d:
f0:bc:ad:d7:7a:f7:00:0b:b0:17:a8:69:bd:e4:17:3e:9d:65:
50:2d:4f:ec:3b:e4:9c:c6:7c:ee:5c:a6:13:81:3b:18:79:c7:
db:6e:0d:10:f8:16:23:2c:4a:3e:67:d5:01:1f:79:98:6f:1e:
03:78:1a:cb:30:e6:b8:57:87:4b:df:53:f0:a4:05:03:b3:68:
4c:5f:db:44:7b:e4:69:e3:96:82:ed:a8:20:13:34:3a:8d:9f:
e0:6a:c9:38:05:93:38:18:7d:56:a1:83:cc:37:e8:f0:19:1b:
18:28:a6:c2:3d:f1:26:4e:1e:e0:ec:29:c3:8c:46:52:97:cb:
8e:41:6d:a5:3b:14:2c:fe:c1:5f:f2:af:b9:72:63:82:9b:a2:
73:12:ab:8a:c6:cf:ce:14:7d:a1:5c:09:c1:c2:bc:30:0c:85:
85:0d:1b:32:20:7d:03:eb:86:56:65:c7:af:7e:6a:8d:1b:e6:
3e:8c:79:7d:81:d2:eb:3f:56:aa:a9:27:e2:28:84:a5:c9:92:
d1:4d:d6:3a:74:d2:01:d5:a4:83:df:36:9c:1c:9d:49:96:d4:
ad:ff:0c:dc:7c:28:2c:6d:38:11:1e:d8:0b:2a:31:5c:7f:fc:
d9:86:0d:89
```

### Шаг 2. Заполнение заявки на сертификат
[Скачайте заявку](https://yookassa.ru/docs/ssl_cert_form.doc) на сертификат, заполните и распечатайте. Поставьте подпись и печать. Отсканируйте.

|**Параметр**|**Описание**|
|:-----------|:---------|
|CN|Должно соответствовать значению параметра Common Name (eg, YOUR name). Например, /business/predpriyatie.|
|Электронная подпись запроса на сертификат|Текстовое представление, полученное на предыдущем шаге.|
|Наименование организации латинскими буквами|Должно соответствовать значению параметра Organization Name (eg, company) [Internet Widgits Pty Ltd].|
|<span align="top">Причина запроса</span>|Возможные варианты: <ul><li>первоначальный — для получения первого сертификата;</li><li>плановая замена — для замены сертификата, у которого закончился срок действия;</li><li>замена скомпрометированного — для замены ранее выпущенного сертификата при нарушении безопасности;</li><li>добавление сервера — для использования нового сертификата на дополнительных серверах или сервисах.</li></ul> |
|Контактное лицо (ФИО, телефон, e-mail)|Контакты специалиста для связи при возникновении вопросов по выданному сертификату.|

### Шаг 3. Обмен данными с ЮKassa
Отправьте файл запроса на сертификат (request.csr) и скан заявки по электронной почте своему менеджеру ЮKassa. В ответ на заявку менеджер в течение 2 рабочих дней пришлет файл с сертификатом. Срок действия сертификата 1 год.  
Разместите полученный сертификат на своем сервере

## Запрос баланса

Запрос balance возвращает разницу между суммой, которую контрагент выплатил своим клиентам, и суммой, 
которую контрагент перечислил на номер баланса выплат.

[Создание запроса в документации](https://yookassa.ru/docs/payouts/api/balance)

```php
require_once '../vendor/autoload.php';

// Создание ключницы и экземпляра клиента
$keychain = new YooKassaPayout\Request\Keychain('./250000.cer', './privateKey.pem', 12345);
$client  = new YooKassaPayout\Client('250000', $keychain);

// Получение информации о балансе
try {
    $response = $client->getBalance();
    $balance = $response->getXmlResponse();
    var_dump($balance);
} catch (\Exception $e) {
    print_r($e->getMessage());
}
```
